# Hyperspectral Fourier-Mellin algorithm (HYFM) on GPU

## Requirements

* NVIDIA GPU with compute capability 6.1.
* Ubuntu 14.04 or later

## Dependencies

* [NVIDIA CUDA Toolkit](https://developer.nvidia.com/cuda-downloads)
* Install: `sudo apt-get install libmatio-dev`

## Usage

Run `./HYFMGPU` with the following parameters:

`./HYFMGPU <reference_image.mat> <target_image.mat>`

Outputs:

* Textual result in console: scale, angle of rotation, and shifts over x and y axis.
* An original band of reference and target images in PGM format.
* A registered band image in PGM format.
* Registered hyperspectral image in MAT format.

## Additional program

`rot_scal` allows generating new target images with specific a scale and angle of rotation for testing the performance of the method.

Use:

`./rot_scal <image.mat> <scale> <angle>`

The output image is saved in the same directory with the name `rot_scal_out.mat`.

## Examples

Using Santa Barbara Line images:

`./HYFMGPU SantaBarbaraLine2013.mat SantaBarbaraLine2014.mat`

Using Pavia University image:

1. `./rot_scal PaviaUniversity.mat 2.0 90`
2. `./HYFMGPU PaviaUniversity.mat ./rot_scal_out.mat`

## Citation

This algorithm was presented in the paper "GPU Accelerated FFT-based Registration of Hyperspectral Scenes" that is under revision. If you use this program in your research projects, we encourage you to please cite our work:

```
@article{alvaro2017hyfmgpu,
    title = {{GPU} Accelerated {FFT-based} Registration of Hyperspectral Scenes},
    journal = {IEEE Journal of Selected Topics in Applied Earth Observations and Remote Sensing},
    volume = {XX},
    number = {XX},
    year = {XXXX},
    pages = {XXXX-XXXX},
    author={Ord\'o\~nez, \'Alvaro and Arg{\"u}ello, Francisco and Heras, Dora B.}
}
```
